==> monaco-vscode-user-data-sync-service-override-4.0.0.tgz: package/vscode/src/vs/platform/userDataSync/common/userDataSyncLocalStoreService.js <==
import { __decorate, __param } from '../../../../../../external/tslib/tslib.es6.js';
import { Promises } from 'vscode/vscode/vs/base/common/async';
import { VSBuffer } from 'vscode/vscode/vs/base/common/buffer';
import { toLocalISOString } from 'vscode/vscode/vs/base/common/date';
import { Disposable } from 'vscode/vscode/vs/base/common/lifecycle';
import { joinPath } from 'vscode/vscode/vs/base/common/resources';
import { IConfigurationService } from 'vscode/vscode/vs/platform/configuration/common/configuration';
import { IEnvironmentService } from 'vscode/vscode/vs/platform/environment/common/environment';
import { toFileOperationResult, IFileService } from 'vscode/vscode/vs/platform/files/common/files';
import { IUserDataProfilesService } from 'vscode/vscode/vs/platform/userDataProfile/common/userDataProfile';
import { ALL_SYNC_RESOURCES, IUserDataSyncLogService } from 'vscode/vscode/vs/platform/userDataSync/common/userDataSync';

let UserDataSyncLocalStoreService = class UserDataSyncLocalStoreService extends Disposable {
    constructor(environmentService, fileService, configurationService, logService, userDataProfilesService) {
        super();
        this.environmentService = environmentService;
        this.fileService = fileService;
        this.configurationService = configurationService;
        this.logService = logService;
        this.userDataProfilesService = userDataProfilesService;
        this.cleanUp();
    }
    async cleanUp() {
        for (const profile of this.userDataProfilesService.profiles) {
            for (const resource of ALL_SYNC_RESOURCES) {
                try {
                    await this.cleanUpBackup(this.getResourceBackupHome(resource, profile.isDefault ? undefined : profile.id));
                }
                catch (error) {
                    this.logService.error(error);
                }
            }
        }
        let stat;
        try {
            stat = await this.fileService.resolve(this.environmentService.userDataSyncHome);
        }
        catch (error) {
            if (toFileOperationResult(error) !== 1 ) {
                this.logService.error(error);
            }
            return;
        }
        if (stat.children) {
            for (const child of stat.children) {
                if (child.isDirectory && !( this.userDataProfilesService.profiles.some(profile => profile.id === child.name))) {
                    try {
                        this.logService.info('Deleting non existing profile from backup', child.resource.path);
                        await this.fileService.del(child.resource, { recursive: true });
                    }
                    catch (error) {
                        this.logService.error(error);
                    }
                }
            }
        }
    }
    async getAllResourceRefs(resource, collection, root) {
        const folder = this.getResourceBackupHome(resource, collection, root);
        try {
            const stat = await this.fileService.resolve(folder);
            if (stat.children) {
                const all = stat.children.filter(stat => stat.isFile && !stat.name.startsWith('lastSync')).sort().reverse();
                return ( all.map(stat => ({
                    ref: stat.name,
                    created: this.getCreationTime(stat)
                })));
            }
        }
        catch (error) {
            if (toFileOperationResult(error) !== 1 ) {
                throw error;
            }
        }
        return [];
    }
    async resolveResourceContent(resourceKey, ref, collection, root) {
        const folder = this.getResourceBackupHome(resourceKey, collection, root);
        const file = joinPath(folder, ref);
        try {
            const content = await this.fileService.readFile(file);
            return ( content.value.toString());
        }
        catch (error) {
            this.logService.error(error);
            return null;
        }
    }
    async writeResource(resourceKey, content, cTime, collection, root) {
        const folder = this.getResourceBackupHome(resourceKey, collection, root);
        const resource = joinPath(folder, `${toLocalISOString(cTime).replace(/-|:|\.\d+Z$/g, '')}.json`);
        try {
            await this.fileService.writeFile(resource, VSBuffer.fromString(content));
        }
        catch (e) {
            this.logService.error(e);
        }
    }
    getResourceBackupHome(resource, collection, root = this.environmentService.userDataSyncHome) {
        return joinPath(root, ...(collection ? [collection, resource] : [resource]));
    }
    async cleanUpBackup(folder) {
        try {
            try {
                if (!(await this.fileService.exists(folder))) {
                    return;
                }
            }
            catch (e) {
                return;
            }
            const stat = await this.fileService.resolve(folder);
            if (stat.children) {
                const all = stat.children.filter(stat => stat.isFile && /^\d{8}T\d{6}(\.json)?$/.test(stat.name)).sort();
                const backUpMaxAge = 1000 * 60 * 60 * 24 * ((this.configurationService.getValue('sync.localBackupDuration') || 30) );
                let toDelete = all.filter(stat => Date.now() - this.getCreationTime(stat) > backUpMaxAge);
                const remaining = all.length - toDelete.length;
                if (remaining < 10) {
                    toDelete = toDelete.slice(10 - remaining);
                }
                await Promises.settled(( toDelete.map(async (stat) => {
                    this.logService.info('Deleting from backup', stat.resource.path);
                    await this.fileService.del(stat.resource);
                })));
            }
        }
        catch (e) {
            this.logService.error(e);
        }
    }
    getCreationTime(stat) {
        return ( new Date(
            parseInt(stat.name.substring(0, 4)),
            parseInt(stat.name.substring(4, 6)) - 1,
            parseInt(stat.name.substring(6, 8)),
            parseInt(stat.name.substring(9, 11)),
            parseInt(stat.name.substring(11, 13)),
            parseInt(stat.name.substring(13, 15))
        )).getTime();
    }
};
UserDataSyncLocalStoreService = ( __decorate([
    ( __param(0, IEnvironmentService)),
    ( __param(1, IFileService)),
    ( __param(2, IConfigurationService)),
    ( __param(3, IUserDataSyncLogService)),
    ( __param(4, IUserDataProfilesService))
], UserDataSyncLocalStoreService));

export { UserDataSyncLocalStoreService };

==> monaco-vscode-user-data-sync-service-override-4.4.0.tgz: package/vscode/src/vs/platform/userDataSync/common/userDataSyncLocalStoreService.js <==
import { __decorate, __param } from 'vscode/external/tslib/tslib.es6.js';
import { Promises } from 'vscode/vscode/vs/base/common/async';
import { VSBuffer } from 'vscode/vscode/vs/base/common/buffer';
import { toLocalISOString } from 'vscode/vscode/vs/base/common/date';
import { Disposable } from 'vscode/vscode/vs/base/common/lifecycle';
import { joinPath } from 'vscode/vscode/vs/base/common/resources';
import { IConfigurationService } from 'vscode/vscode/vs/platform/configuration/common/configuration';
import { IEnvironmentService } from 'vscode/vscode/vs/platform/environment/common/environment';
import { IFileService, toFileOperationResult } from 'vscode/vscode/vs/platform/files/common/files';
import { IUserDataProfilesService } from 'vscode/vscode/vs/platform/userDataProfile/common/userDataProfile';
import { IUserDataSyncLogService, ALL_SYNC_RESOURCES } from 'vscode/vscode/vs/platform/userDataSync/common/userDataSync';

let UserDataSyncLocalStoreService = class UserDataSyncLocalStoreService extends Disposable {
    constructor(environmentService, fileService, configurationService, logService, userDataProfilesService) {
        super();
        this.environmentService = environmentService;
        this.fileService = fileService;
        this.configurationService = configurationService;
        this.logService = logService;
        this.userDataProfilesService = userDataProfilesService;
        this.cleanUp();
    }
    async cleanUp() {
        for (const profile of this.userDataProfilesService.profiles) {
            for (const resource of ALL_SYNC_RESOURCES) {
                try {
                    await this.cleanUpBackup(this.getResourceBackupHome(resource, profile.isDefault ? undefined : profile.id));
                }
                catch (error) {
                    this.logService.error(error);
                }
            }
        }
        let stat;
        try {
            stat = await this.fileService.resolve(this.environmentService.userDataSyncHome);
        }
        catch (error) {
            if (toFileOperationResult(error) !== 1 ) {
                this.logService.error(error);
            }
            return;
        }
        if (stat.children) {
            for (const child of stat.children) {
                if (child.isDirectory && !( this.userDataProfilesService.profiles.some(profile => profile.id === child.name))) {
                    try {
                        this.logService.info('Deleting non existing profile from backup', child.resource.path);
                        await this.fileService.del(child.resource, { recursive: true });
                    }
                    catch (error) {
                        this.logService.error(error);
                    }
                }
            }
        }
    }
    async getAllResourceRefs(resource, collection, root) {
        const folder = this.getResourceBackupHome(resource, collection, root);
        try {
            const stat = await this.fileService.resolve(folder);
            if (stat.children) {
                const all = stat.children.filter(stat => stat.isFile && !stat.name.startsWith('lastSync')).sort().reverse();
                return ( all.map(stat => ({
                    ref: stat.name,
                    created: this.getCreationTime(stat)
                })));
            }
        }
        catch (error) {
            if (toFileOperationResult(error) !== 1 ) {
                throw error;
            }
        }
        return [];
    }
    async resolveResourceContent(resourceKey, ref, collection, root) {
        const folder = this.getResourceBackupHome(resourceKey, collection, root);
        const file = joinPath(folder, ref);
        try {
            const content = await this.fileService.readFile(file);
            return ( content.value.toString());
        }
        catch (error) {
            this.logService.error(error);
            return null;
        }
    }
    async writeResource(resourceKey, content, cTime, collection, root) {
        const folder = this.getResourceBackupHome(resourceKey, collection, root);
        const resource = joinPath(folder, `${toLocalISOString(cTime).replace(/-|:|\.\d+Z$/g, '')}.json`);
        try {
            await this.fileService.writeFile(resource, VSBuffer.fromString(content));
        }
        catch (e) {
            this.logService.error(e);
        }
    }
    getResourceBackupHome(resource, collection, root = this.environmentService.userDataSyncHome) {
        return joinPath(root, ...(collection ? [collection, resource] : [resource]));
    }
    async cleanUpBackup(folder) {
        try {
            try {
                if (!(await this.fileService.exists(folder))) {
                    return;
                }
            }
            catch (e) {
                return;
            }
            const stat = await this.fileService.resolve(folder);
            if (stat.children) {
                const all = stat.children.filter(stat => stat.isFile && /^\d{8}T\d{6}(\.json)?$/.test(stat.name)).sort();
                const backUpMaxAge = 1000 * 60 * 60 * 24 * ((this.configurationService.getValue('sync.localBackupDuration') || 30) );
                let toDelete = all.filter(stat => Date.now() - this.getCreationTime(stat) > backUpMaxAge);
                const remaining = all.length - toDelete.length;
                if (remaining < 10) {
                    toDelete = toDelete.slice(10 - remaining);
                }
                await Promises.settled(( toDelete.map(async (stat) => {
                    this.logService.info('Deleting from backup', stat.resource.path);
                    await this.fileService.del(stat.resource);
                })));
            }
        }
        catch (e) {
            this.logService.error(e);
        }
    }
    getCreationTime(stat) {
        return ( new Date(
            parseInt(stat.name.substring(0, 4)),
            parseInt(stat.name.substring(4, 6)) - 1,
            parseInt(stat.name.substring(6, 8)),
            parseInt(stat.name.substring(9, 11)),
            parseInt(stat.name.substring(11, 13)),
            parseInt(stat.name.substring(13, 15))
        )).getTime();
    }
};
UserDataSyncLocalStoreService = ( __decorate([
    ( __param(0, IEnvironmentService)),
    ( __param(1, IFileService)),
    ( __param(2, IConfigurationService)),
    ( __param(3, IUserDataSyncLogService)),
    ( __param(4, IUserDataProfilesService))
], UserDataSyncLocalStoreService));

export { UserDataSyncLocalStoreService };
